@@ -563,8 +563,13 @@ gboolean
 cogl_offscreen_set_to_texture (CoglHandle handle,
                                CoglHandle texhandle)
 {
+  CoglOffscreen *offscreen;
+  CoglFramebuffer *framebuffer;
+  int width, height;
   GLuint fbo_handle;
   GSList *renderbuffers = NULL;
+
+  _COGL_GET_CONTEXT (ctx, FALSE);
   
   if (!cogl_is_offscreen(handle))
     return FALSE;
@@ -576,20 +581,38 @@ cogl_offscreen_set_to_texture (CoglHandle handle,
     return FALSE;
 
   _cogl_texture_set_filters (texhandle, GL_NEAREST, GL_NEAREST);
-
-  if (try_creating_fbo_alternatives (texhandle, &renderbuffers, &fbo_handle))
-    {
-      CoglOffscreen *offscreen;
-      CoglFramebuffer *framebuffer;
     
-      offscreen = _cogl_offscreen_pointer_from_handle(handle);
-      framebuffer = COGL_FRAMEBUFFER (offscreen);
+  offscreen = _cogl_offscreen_pointer_from_handle(handle);
+  framebuffer = COGL_FRAMEBUFFER (offscreen);
+
+  width = cogl_texture_get_width (texhandle);
+  height = cogl_texture_get_height (texhandle);
+
+  if (width == framebuffer->width && height == framebuffer->height)
+    {
+      GLuint tex_gl_handle;
+      GLenum tex_gl_target;
+      
+      if (!cogl_texture_get_gl_texture (texhandle, &tex_gl_handle, &tex_gl_target))
+	return FALSE;
+
+      _cogl_journal_flush ();
+      ctx->dirty_bound_framebuffer = 1;
+
+      GE (glBindFramebuffer (GL_FRAMEBUFFER, offscreen->fbo_handle));
+      GE (glFramebufferTexture2D (GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0,
+				  tex_gl_target, tex_gl_handle, 0));
+            
+      return TRUE;
+    }
+  else if (try_creating_fbo_alternatives (texhandle, &renderbuffers, &fbo_handle))
+    {
     
       free_buffers (offscreen);
       
       offscreen->texture = cogl_handle_ref (texhandle);
-      framebuffer->width = cogl_texture_get_width (texhandle);
-      framebuffer->height = cogl_texture_get_height (texhandle);
+      framebuffer->width = width;
+      framebuffer->height = height;
 
       offscreen->fbo_handle = fbo_handle;
       offscreen->renderbuffers = renderbuffers;
