@@ -137,6 +137,7 @@
 #include "cogl-vertex-buffer-private.h"
 #include "cogl-texture-private.h"
 #include "cogl-material-private.h"
+#include "cogl-material-opengl-private.h"
 #include "cogl-primitives.h"
 #include "cogl-framebuffer-private.h"
 #include "cogl-journal-private.h"
@@ -711,7 +712,7 @@ filter_already_submitted_attribute (CoglVertexBufferAttrib *attribute,
 
       /* Mark all but the matched attribute as UNUSED, so that when we
        * finish filtering all our attributes any attrributes still
-       * marked as UNUSED can be removed from the their cogl_vbo */
+       * marked as UNUSED can be removed from their cogl_vbo */
       for (tmp2 = cogl_vbo->attributes; tmp2 != NULL; tmp2 = tmp2->next)
 	{
 	  CoglVertexBufferAttrib *vbo_attribute = tmp2->data;
@@ -1532,13 +1533,20 @@ enable_state_for_drawing_buffer (CoglVertexBuffer *buffer)
   if (buffer->new_attributes)
     cogl_vertex_buffer_submit_real (buffer);
 
-  options.flags =
-    COGL_MATERIAL_FLUSH_FALLBACK_MASK;
+  options.flags = 0;
   memset (&options.wrap_mode_overrides, 0,
           sizeof (options.wrap_mode_overrides));
 
   _cogl_bitmask_clear_all (&ctx->temp_bitmask);
 
+  /* NB: _cogl_framebuffer_flush_state may disrupt various state (such
+   * as the material state) when flushing the clip stack, so should
+   * always be done first when preparing to draw. We need to do this
+   * before setting up the array pointers because setting up the clip
+   * stack can cause some drawing which would change the array
+   * pointers. */
+  _cogl_framebuffer_flush_state (_cogl_get_framebuffer (), 0);
+
   for (tmp = buffer->submitted_vbos; tmp != NULL; tmp = tmp->next)
     {
       CoglVertexBufferVBO *cogl_vbo = tmp->data;
@@ -1682,10 +1690,10 @@ enable_state_for_drawing_buffer (CoglVertexBuffer *buffer)
                 COGL_MATERIAL_WRAP_MODE_OVERRIDE_REPEAT;
               options.flags |= COGL_MATERIAL_FLUSH_WRAP_MODE_OVERRIDES;
             }
-          if (_cogl_material_layer_get_wrap_mode_r (layer) ==
+          if (cogl_material_layer_get_wrap_mode_p (layer) ==
               COGL_MATERIAL_WRAP_MODE_AUTOMATIC)
             {
-              options.wrap_mode_overrides.values[i].r =
+              options.wrap_mode_overrides.values[i].p =
                 COGL_MATERIAL_WRAP_MODE_OVERRIDE_REPEAT;
               options.flags |= COGL_MATERIAL_FLUSH_WRAP_MODE_OVERRIDES;
             }
@@ -1728,12 +1736,11 @@ enable_state_for_drawing_buffer (CoglVertexBuffer *buffer)
   /* Disable any tex coord arrays that we didn't use */
   _cogl_disable_other_texcoord_arrays (&ctx->temp_bitmask);
 
-  /* NB: _cogl_framebuffer_flush_state may disrupt various state (such
-   * as the material state) when flushing the clip stack, so should
-   * always be done first when preparing to draw. */
-  _cogl_framebuffer_flush_state (_cogl_get_framebuffer (), 0);
-
-  options.fallback_layers = fallback_layers;
+  if (fallback_layers)
+    {
+      options.fallback_layers = fallback_layers;
+      options.flags |= COGL_MATERIAL_FLUSH_FALLBACK_MASK;
+    }
 
   if (G_UNLIKELY (options.flags))
     {
