@@ -138,7 +138,7 @@ on_paint (ClutterActor *actor, void *state)
   /* Comment this out if you want visual feedback of what this test
    * paints.
    */
-//  clutter_main_quit ();
+  clutter_main_quit ();
 }
 
 static gboolean
